@@ -8,9 +8,9 @@
 #include "soup-soap-message.h"
 #include "soup-uri.h"
 
-#define PARENT_TYPE SOUP_TYPE_MESSAGE
+G_DEFINE_TYPE (SoupSoapMessage, soup_soap_message, SOUP_TYPE_MESSAGE)
 
-struct _SoupSoapMessagePrivate {
+typedef struct {
 	/* Serialization fields */
 	xmlDocPtr doc;
 	xmlNodePtr last_node;
@@ -20,77 +20,58 @@ struct _SoupSoapMessagePrivate {
 	gchar *env_uri;
 	gboolean body_started;
 	gchar *action;
-};
-
-static GObjectClass *parent_class = NULL;
+} SoupSoapMessagePrivate;
+#define SOUP_SOAP_MESSAGE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SOUP_TYPE_SOAP_MESSAGE, SoupSoapMessagePrivate))
 
 static void
 finalize (GObject *object)
 {
-	SoupSoapMessage *msg = SOUP_SOAP_MESSAGE (object);
-	SoupSoapMessagePrivate *priv;
-
-	/* free memory */
-
-	priv = msg->priv;
+	SoupSoapMessagePrivate *priv = SOUP_SOAP_MESSAGE_GET_PRIVATE (object);
 
 	if (priv->doc) 
 		xmlFreeDoc (priv->doc);
-	priv->doc = NULL;
-
 	if (priv->action)
 		g_free (priv->action);
-	priv->action = NULL;
-
-	 if (priv->env_uri)
+	if (priv->env_uri)
                 g_free (priv->env_uri);
-	 priv->env_uri = NULL;
-
 	if (priv->env_prefix)
                 g_free (priv->env_prefix);
-        priv->env_prefix = NULL;
 
-	g_free (msg->priv);
-	msg->priv = NULL;
-
-	parent_class->finalize (object);
+	G_OBJECT_CLASS (soup_soap_message_parent_class)->finalize (object);
 }
 
 static void
-class_init (SoupSoapMessageClass *klass)
+soup_soap_message_class_init (SoupSoapMessageClass *soup_soap_message_class)
 {
-	GObjectClass *object_class;
+	GObjectClass *object_class = G_OBJECT_CLASS (soup_soap_message_class);
 
-	parent_class = g_type_class_peek_parent (klass);
-
-	object_class = G_OBJECT_CLASS (klass);
 	object_class->finalize = finalize;
 }
 
 static void
-init (SoupSoapMessage *msg, SoupSoapMessageClass *klass)
+soup_soap_message_init (SoupSoapMessage *msg)
 {
-	msg->priv = g_new0 (SoupSoapMessagePrivate, 1);
+	SoupSoapMessagePrivate *priv = SOUP_SOAP_MESSAGE_GET_PRIVATE (msg);
 
 	/* initialize XML structures */
-	msg->priv->doc = xmlNewDoc ("1.0");
-	msg->priv->doc->standalone = FALSE;
-	msg->priv->doc->encoding = g_strdup ("UTF-8");
+	priv->doc = xmlNewDoc ("1.0");
+	priv->doc->standalone = FALSE;
+	priv->doc->encoding = g_strdup ("UTF-8");
 }
 
-SOUP_MAKE_TYPE (soup_soap_message, SoupSoapMessage, class_init, init, PARENT_TYPE)
 
 static xmlNsPtr
 fetch_ns (SoupSoapMessage *msg, const char *prefix, const char *ns_uri)
 {
+	SoupSoapMessagePrivate *priv = SOUP_SOAP_MESSAGE_GET_PRIVATE (msg);
         xmlNsPtr ns = NULL;
                                                                                 
         if (prefix && ns_uri)
-                ns = xmlNewNs (msg->priv->last_node, ns_uri, prefix);
+                ns = xmlNewNs (priv->last_node, ns_uri, prefix);
         else if (prefix && !ns_uri) {
-                ns = xmlSearchNs (msg->priv->doc, msg->priv->last_node, prefix);
+                ns = xmlSearchNs (priv->doc, priv->last_node, prefix);
                 if (!ns)
-			ns = xmlNewNs (msg->priv->last_node, "", prefix);
+			ns = xmlNewNs (priv->last_node, "", prefix);
         }
                                                                                 
         return ns;
@@ -100,6 +81,10 @@ fetch_ns (SoupSoapMessage *msg, const char *prefix, const char *ns_uri)
  * soup_soap_message_new:
  * @method: the HTTP method for the created request.
  * @uri_string: the destination endpoint (as a string).
+ * @standalone: ??? FIXME
+ * @xml_encoding: ??? FIXME
+ * @env_prefix: ??? FIXME
+ * @env_uri: ??? FIXME
  *
  * Creates a new empty #SoupSoapMessage, which will connect to @uri_string.
  *
@@ -130,8 +115,12 @@ soup_soap_message_new (const char *method, const char *uri_string,
  * soup_soap_message_new_from_uri:
  * @method: the HTTP method for the created request.
  * @uri: the destination endpoint (as a #SoupUri).
+ * @standalone: ??? FIXME
+ * @xml_encoding: ??? FIXME
+ * @env_prefix: ??? FIXME
+ * @env_uri: ??? FIXME
  *
- * * Creates a new empty #SoupSoapMessage, which will connect to @uri
+ * Creates a new empty #SoupSoapMessage, which will connect to @uri
  *
  * Returns: the new #SoupSoapMessage
  */
@@ -141,21 +130,23 @@ soup_soap_message_new_from_uri (const char *method, const SoupUri *uri,
 				const char *env_prefix, const char *env_uri)
 {
 	SoupSoapMessage *msg;
+	SoupSoapMessagePrivate *priv;
 
 	msg = g_object_new (SOUP_TYPE_SOAP_MESSAGE, NULL);
+	priv = SOUP_SOAP_MESSAGE_GET_PRIVATE (msg);
 	SOUP_MESSAGE (msg)->method = method ? method : SOUP_METHOD_GET;
 	soup_message_set_uri (SOUP_MESSAGE (msg), (const SoupUri *) uri);
 
-	msg->priv->doc->standalone = standalone;
+	priv->doc->standalone = standalone;
 
 	if (xml_encoding) {
-		g_free ((char *) msg->priv->doc->encoding);
-		msg->priv->doc->encoding = g_strdup (xml_encoding);
+		g_free ((char *) priv->doc->encoding);
+		priv->doc->encoding = g_strdup (xml_encoding);
 	}
 
 	if (env_prefix || env_uri) {
-		msg->priv->env_prefix = g_strdup (env_prefix);
-		msg->priv->env_uri = g_strdup (env_uri);
+		priv->env_prefix = g_strdup (env_prefix);
+		priv->env_uri = g_strdup (env_uri);
 	}
 
 	return msg;
@@ -170,38 +161,41 @@ soup_soap_message_new_from_uri (const char *method, const SoupUri *uri,
 void
 soup_soap_message_start_envelope (SoupSoapMessage *msg)
 {
+	SoupSoapMessagePrivate *priv;
+
 	g_return_if_fail (SOUP_IS_SOAP_MESSAGE (msg));
+	priv = SOUP_SOAP_MESSAGE_GET_PRIVATE (msg);
 
-	msg->priv->last_node = msg->priv->doc->xmlRootNode =
-		xmlNewDocNode (msg->priv->doc, NULL, "Envelope", NULL);
+	priv->last_node = priv->doc->xmlRootNode =
+		xmlNewDocNode (priv->doc, NULL, "Envelope", NULL);
 
-	msg->priv->soap_ns = xmlNewNs (msg->priv->doc->xmlRootNode,
-				       msg->priv->env_uri ? msg->priv->env_uri :
-				       "http://schemas.xmlsoap.org/soap/envelope/",
-				       msg->priv->env_prefix ? msg->priv->env_prefix : "SOAP-ENV");
-	if (msg->priv->env_uri) {
-		g_free (msg->priv->env_uri);
-		msg->priv->env_uri = NULL;
+	priv->soap_ns = xmlNewNs (priv->doc->xmlRootNode,
+				  priv->env_uri ? priv->env_uri :
+				  "http://schemas.xmlsoap.org/soap/envelope/",
+				  priv->env_prefix ? priv->env_prefix : "SOAP-ENV");
+	if (priv->env_uri) {
+		g_free (priv->env_uri);
+		priv->env_uri = NULL;
 	}
-	if (msg->priv->env_prefix) {
-		g_free (msg->priv->env_prefix);
-		msg->priv->env_prefix = NULL;
+	if (priv->env_prefix) {
+		g_free (priv->env_prefix);
+		priv->env_prefix = NULL;
 	}
 
-	xmlSetNs (msg->priv->doc->xmlRootNode, msg->priv->soap_ns);
+	xmlSetNs (priv->doc->xmlRootNode, priv->soap_ns);
 
-	xmlNewNs (msg->priv->doc->xmlRootNode,
+	xmlNewNs (priv->doc->xmlRootNode,
 		  "http://schemas.xmlsoap.org/soap/encoding/",
                   "SOAP-ENC");
-	xmlNewNs (msg->priv->doc->xmlRootNode,
+	xmlNewNs (priv->doc->xmlRootNode,
                   "http://www.w3.org/1999/XMLSchema",
                   "xsd");
-	xmlNewNs (msg->priv->doc->xmlRootNode,
+	xmlNewNs (priv->doc->xmlRootNode,
 		  "http://schemas.xmlsoap.org/soap/envelope/",
 		  "SOAP-ENV");
-	msg->priv->xsi_ns = xmlNewNs (msg->priv->doc->xmlRootNode,
-				      "http://www.w3.org/1999/XMLSchema-instance",
-				      "xsi");
+	priv->xsi_ns = xmlNewNs (priv->doc->xmlRootNode,
+				 "http://www.w3.org/1999/XMLSchema-instance",
+				 "xsi");
 }
 
 /**
@@ -225,20 +219,23 @@ soup_soap_message_end_envelope (SoupSoapMessage *msg)
 void
 soup_soap_message_start_body (SoupSoapMessage *msg)
 {
-	g_return_if_fail (SOUP_IS_SOAP_MESSAGE (msg));
+	SoupSoapMessagePrivate *priv;
 
-	if (msg->priv->body_started)
+	g_return_if_fail (SOUP_IS_SOAP_MESSAGE (msg));
+	priv = SOUP_SOAP_MESSAGE_GET_PRIVATE (msg);
+
+	if (priv->body_started)
 		return;
 
-	msg->priv->last_node = xmlNewChild (msg->priv->last_node,
-					    msg->priv->soap_ns,
-					    "Body", NULL);
+	priv->last_node = xmlNewChild (priv->last_node,
+				       priv->soap_ns,
+				       "Body", NULL);
 
-	msg->priv->body_started = TRUE;
+	priv->body_started = TRUE;
 }
 
 /**
- * soup_soap_end_body:
+ * soup_soap_message_end_body:
  * @msg: the %SoupSoapMessage.
  *
  * Closes the SOAP Body element.
@@ -251,23 +248,24 @@ soup_soap_message_end_body (SoupSoapMessage *msg)
 
 /**
  * soup_soap_message_start_element:
- * @msg: the %SoupSoapMessage.
+ * @msg: the #SoupSoapMessage.
  * @name: the element name.
  * @prefix: the namespace prefix
  * @ns_uri: the namespace URI
  *
- * Starts a new arbitrary message element, with @name as the element name,
- * @prefix as the XML Namespace prefix, and @ns_uri as the XML Namespace uri for * the created element.
+ * Starts a new arbitrary message element, with @name as the element
+ * name, @prefix as the XML Namespace prefix, and @ns_uri as the XML
+ * Namespace uri for * the created element.
  *
- * Passing @prefix with no @ns_uri will cause a recursive search for an
- * existing namespace with the same prefix. Failing that a new ns will be
- * created with an empty uri.
+ * Passing @prefix with no @ns_uri will cause a recursive search for
+ * an existing namespace with the same prefix. Failing that a new ns
+ * will be created with an empty uri.
  *
- * Passing both @prefix and @ns_uri always causes new namespace attribute
- * creation.
+ * Passing both @prefix and @ns_uri always causes new namespace
+ * attribute creation.
  *
- * Passing NULL for both @prefix and @ns_uri causes no prefix to be used, and
- * the element will be in the default namespace.
+ * Passing NULL for both @prefix and @ns_uri causes no prefix to be
+ * used, and the element will be in the default namespace.
  */
 void
 soup_soap_message_start_element (SoupSoapMessage *msg,
@@ -275,44 +273,50 @@ soup_soap_message_start_element (SoupSoapMessage *msg,
 				 const char *prefix,
 				 const char *ns_uri)
 {
+	SoupSoapMessagePrivate *priv;
+
 	g_return_if_fail (SOUP_IS_SOAP_MESSAGE (msg));
+	priv = SOUP_SOAP_MESSAGE_GET_PRIVATE (msg);
 
-	msg->priv->last_node = xmlNewChild (msg->priv->last_node, NULL, name, NULL);
+	priv->last_node = xmlNewChild (priv->last_node, NULL, name, NULL);
 
-	xmlSetNs (msg->priv->last_node, fetch_ns (msg, prefix, ns_uri));
+	xmlSetNs (priv->last_node, fetch_ns (msg, prefix, ns_uri));
 
-	if (msg->priv->body_started && !msg->priv->action)
-		msg->priv->action = g_strconcat (ns_uri ? ns_uri : "",
-						 "#", name, NULL);
+	if (priv->body_started && !priv->action)
+		priv->action = g_strconcat (ns_uri ? ns_uri : "",
+					    "#", name, NULL);
 }
 
 /**
  * soup_soap_message_end_element:
- * @msg: the %SoupSoapMessage.
+ * @msg: the #SoupSoapMessage.
  *
  * Closes the current message element.
  */
 void
 soup_soap_message_end_element (SoupSoapMessage *msg)
 {
-	g_return_if_fail (SOUP_IS_SOAP_MESSAGE (msg));
+	SoupSoapMessagePrivate *priv;
 
-	msg->priv->last_node = msg->priv->last_node->parent;
+	g_return_if_fail (SOUP_IS_SOAP_MESSAGE (msg));
+	priv = SOUP_SOAP_MESSAGE_GET_PRIVATE (msg);
+
+	priv->last_node = priv->last_node->parent;
 }
 
 /**
  * soup_soap_message_start_fault:
- * @msg: the %SoupSoapMessage.
+ * @msg: the #SoupSoapMessage.
  * @faultcode: faultcode element value
  * @faultstring: faultstring element value
- * @faultactor: faultactor element value
+ * @faultfactor: faultfactor element value
  *
- * Starts a new SOAP Fault element, creating faultcode, faultstring, and
- * faultactor child elements.
+ * Starts a new SOAP Fault element, creating faultcode, faultstring,
+ * and faultfactor child elements.
  *
  * If you wish to add the faultdetail element, use
- * %soup_soap_message_start_fault_detail, and then %soup_soap_message_start_element
- * to add arbitrary sub-elements.
+ * soup_soap_message_start_fault_detail(), and then
+ * soup_soap_message_start_element() to add arbitrary sub-elements.
  */
 void
 soup_soap_message_start_fault (SoupSoapMessage *msg,
@@ -320,16 +324,19 @@ soup_soap_message_start_fault (SoupSoapMessage *msg,
 			       const char *faultstring,
 			       const char *faultfactor)
 {
+	SoupSoapMessagePrivate *priv;
+
 	g_return_if_fail (SOUP_IS_SOAP_MESSAGE (msg));
+	priv = SOUP_SOAP_MESSAGE_GET_PRIVATE (msg);
 
-	msg->priv->last_node = xmlNewChild (msg->priv->last_node,
-					    msg->priv->soap_ns,
-					    "Fault", NULL);
-	xmlNewChild (msg->priv->last_node, msg->priv->soap_ns, "faultcode", faultcode);
-	xmlNewChild (msg->priv->last_node, msg->priv->soap_ns, "faultstring", faultstring);
+	priv->last_node = xmlNewChild (priv->last_node,
+				       priv->soap_ns,
+				       "Fault", NULL);
+	xmlNewChild (priv->last_node, priv->soap_ns, "faultcode", faultcode);
+	xmlNewChild (priv->last_node, priv->soap_ns, "faultstring", faultstring);
 
-	msg->priv->last_node = xmlNewChild (msg->priv->last_node, msg->priv->soap_ns,
-					    "faultfactor", faultfactor);
+	priv->last_node = xmlNewChild (priv->last_node, priv->soap_ns,
+				       "faultfactor", faultfactor);
 	if (!faultfactor)
 		soup_soap_message_set_null (msg);
 
@@ -338,7 +345,7 @@ soup_soap_message_start_fault (SoupSoapMessage *msg,
 
 /**
  * soup_soap_message_end_fault:
- * @msg: the %SoupSoapMessage.
+ * @msg: the #SoupSoapMessage.
  *
  * Closes the current SOAP Fault element.
  */
@@ -350,25 +357,29 @@ soup_soap_message_end_fault (SoupSoapMessage *msg)
 
 /**
  * soup_soap_message_start_fault_detail:
- * @msg: the %SoupSoapMessage.
+ * @msg: the #SoupSoapMessage.
  *
- * Start the faultdetail child element of the current SOAP Fault element. The
- * faultdetail element allows arbitrary data to be sent in a returned fault.
+ * Start the faultdetail child element of the current SOAP Fault
+ * element. The faultdetail element allows arbitrary data to be sent
+ * in a returned fault.
  **/
 void
 soup_soap_message_start_fault_detail (SoupSoapMessage *msg)
 {
+	SoupSoapMessagePrivate *priv;
+
         g_return_if_fail (SOUP_IS_SOAP_MESSAGE (msg));
+	priv = SOUP_SOAP_MESSAGE_GET_PRIVATE (msg);
                                                                                 
-        msg->priv->last_node = xmlNewChild (msg->priv->last_node,
-					    msg->priv->soap_ns,
-					    "detail",
-					    NULL);
+        priv->last_node = xmlNewChild (priv->last_node,
+				       priv->soap_ns,
+				       "detail",
+				       NULL);
 }
 
 /**
  * soup_soap_message_end_fault_detail:
- * @msg: the %SoupSoapMessage.
+ * @msg: the #SoupSoapMessage.
  *
  * Closes the current SOAP faultdetail element.
  */
@@ -380,28 +391,31 @@ soup_soap_message_end_fault_detail (SoupSoapMessage *msg)
 
 /**
  * soup_soap_message_start_header:
- * @msg: the %SoupSoapMessage.
+ * @msg: the #SoupSoapMessage.
  *
  * Creates a new SOAP Header element. You can call
- * %soup_soap_message_start_header_element after this to add a new header child
- * element. SOAP Header elements allow out-of-band data to be transferred while
- * not interfering with the message body.
+ * soup_soap_message_start_header_element() after this to add a new
+ * header child element. SOAP Header elements allow out-of-band data
+ * to be transferred while not interfering with the message body.
  *
- * This should be called after %soup_soap_message_start_envelope and before
- * %soup_soap_message_start_body.
+ * This should be called after soup_soap_message_start_envelope() and
+ * before soup_soap_message_start_body().
  */
 void
 soup_soap_message_start_header (SoupSoapMessage *msg)
 {
-	g_return_if_fail (SOUP_IS_SOAP_MESSAGE (msg));
+	SoupSoapMessagePrivate *priv;
 
-	msg->priv->last_node = xmlNewChild (msg->priv->last_node, msg->priv->soap_ns,
-					    "Header", NULL);
+	g_return_if_fail (SOUP_IS_SOAP_MESSAGE (msg));
+	priv = SOUP_SOAP_MESSAGE_GET_PRIVATE (msg);
+
+	priv->last_node = xmlNewChild (priv->last_node, priv->soap_ns,
+				       "Header", NULL);
 }
 
 /**
  * soup_soap_message_end_header:
- * @msg: the %SoupSoapMessage.
+ * @msg: the #SoupSoapMessage.
  *
  * Closes the current SOAP Header element.
  */
@@ -413,7 +427,7 @@ soup_soap_message_end_header (SoupSoapMessage *msg)
 
 /**
  * soup_soap_message_start_header_element:
- * @msg: the %SoupSoapMessage.
+ * @msg: the #SoupSoapMessage.
  * @name: name of the header element
  * @must_understand: whether the recipient must understand the header in order
  * to proceed with processing the message
@@ -431,18 +445,21 @@ soup_soap_message_start_header_element (SoupSoapMessage *msg,
 					const char *prefix,
 					const char *ns_uri)
 {
+	SoupSoapMessagePrivate *priv;
+
 	g_return_if_fail (SOUP_IS_SOAP_MESSAGE (msg));
+	priv = SOUP_SOAP_MESSAGE_GET_PRIVATE (msg);
 
 	soup_soap_message_start_element (msg, name, prefix, ns_uri);
 	if (actor_uri)
-		xmlNewNsProp (msg->priv->last_node, msg->priv->soap_ns, "actorUri", actor_uri);
+		xmlNewNsProp (priv->last_node, priv->soap_ns, "actorUri", actor_uri);
 	if (must_understand)
-		xmlNewNsProp (msg->priv->last_node, msg->priv->soap_ns, "mustUnderstand", "1");
+		xmlNewNsProp (priv->last_node, priv->soap_ns, "mustUnderstand", "1");
 }
 
 /**
  * soup_soap_message_end_header_element:
- * @msg: the %SoupSoapMessage.
+ * @msg: the #SoupSoapMessage.
  *
  * Closes the current SOAP header element.
  */
@@ -454,13 +471,13 @@ soup_soap_message_end_header_element (SoupSoapMessage *msg)
 
 /**
  * soup_soap_message_write_int:
- * @msg: the %SoupSoapMessage.
+ * @msg: the #SoupSoapMessage.
  * @i: the integer value to write.
  *
- * Writes the stringified value if @i as the current element's content.
+ * Writes the stringified value of @i as the current element's content.
  */
 void
-soup_soap_message_write_int (SoupSoapMessage *msg, long i)
+soup_soap_message_write_int (SoupSoapMessage *msg, glong i)
 {
 	char *str = g_strdup_printf ("%ld", i);
 	soup_soap_message_write_string (msg, str);
@@ -469,10 +486,10 @@ soup_soap_message_write_int (SoupSoapMessage *msg, long i)
 
 /**
  * soup_soap_message_write_double:
- * @msg: the %SoupSoapMessage.
+ * @msg: the #SoupSoapMessage.
  * @d: the double value to write.
  *
- * Writes the stringified value if @d as the current element's content.
+ * Writes the stringified value of @d as the current element's content.
  */
 void
 soup_soap_message_write_double (SoupSoapMessage *msg, double d)
@@ -484,11 +501,13 @@ soup_soap_message_write_double (SoupSoapMessage *msg, double d)
 
 /**
  * soup_soap_message_write_base64:
- * @msg: the %SoupSoapMessage
+ * @msg: the #SoupSoapMessage
  * @string: the binary data buffer to encode
  * @len: the length of data to encode
  *
- * Writes the Base-64 encoded value of @string as the current element's content. **/
+ * Writes the Base-64 encoded value of @string as the current
+ * element's content.
+ **/
 void
 soup_soap_message_write_base64 (SoupSoapMessage *msg, const char *string, int len)
 {
@@ -499,10 +518,11 @@ soup_soap_message_write_base64 (SoupSoapMessage *msg, const char *string, int le
 
 /**
  * soup_soap_message_write_time:
- * @msg: the %SoupSoapMessage.
+ * @msg: the #SoupSoapMessage.
  * @timeval: pointer to a time_t to encode
  *
- * Writes the stringified value of @timeval as the current element's content.
+ * Writes the stringified value of @timeval as the current element's
+ * content.
  **/
 void
 soup_soap_message_write_time (SoupSoapMessage *msg, const time_t *timeval)
@@ -513,7 +533,7 @@ soup_soap_message_write_time (SoupSoapMessage *msg, const time_t *timeval)
 
 /**
  * soup_soap_message_write_string:
- * @msg: the %SoupSoapMessage.
+ * @msg: the #SoupSoapMessage.
  * @string: string to write.
  *
  * Writes the @string as the current element's content.
@@ -521,60 +541,73 @@ soup_soap_message_write_time (SoupSoapMessage *msg, const time_t *timeval)
 void
 soup_soap_message_write_string (SoupSoapMessage *msg, const char *string)
 {
-	g_return_if_fail (SOUP_IS_SOAP_MESSAGE (msg));
+	SoupSoapMessagePrivate *priv;
 
-	xmlNodeAddContent (msg->priv->last_node, string);
+	g_return_if_fail (SOUP_IS_SOAP_MESSAGE (msg));
+	priv = SOUP_SOAP_MESSAGE_GET_PRIVATE (msg);
+
+	xmlNodeAddContent (priv->last_node, string);
 }
 
 /**
  * soup_soap_message_write_buffer:
- * @msg: the %SoupSoapMessage.
+ * @msg: the #SoupSoapMessage.
  * @buffer: the string data buffer to write.
  * @len: length of @buffer.
  *
- * Writes the string buffer pointed to by @buffer as the current element's content.
+ * Writes the string buffer pointed to by @buffer as the current
+ * element's content.
  */
 void
 soup_soap_message_write_buffer (SoupSoapMessage *msg, const char *buffer, int len)
 {
-	g_return_if_fail (SOUP_IS_SOAP_MESSAGE (msg));
+	SoupSoapMessagePrivate *priv;
 
-	xmlNodeAddContentLen (msg->priv->last_node, buffer, len);
+	g_return_if_fail (SOUP_IS_SOAP_MESSAGE (msg));
+	priv = SOUP_SOAP_MESSAGE_GET_PRIVATE (msg);
+
+	xmlNodeAddContentLen (priv->last_node, buffer, len);
 }
 
 /**
  * soup_soap_message_set_element_type:
- * @msg: the %SoupSoapMessage.
+ * @msg: the #SoupSoapMessage.
  * @xsi_type: the type name for the element.
  *
- * Sets the current element's XML schema xsi:type attribute, which specifies
- * the element's type name.
+ * Sets the current element's XML schema xsi:type attribute, which
+ * specifies the element's type name.
  */
 void
 soup_soap_message_set_element_type (SoupSoapMessage *msg, const char *xsi_type)
 {
-	g_return_if_fail (SOUP_IS_SOAP_MESSAGE (msg));
+	SoupSoapMessagePrivate *priv;
 
-	xmlNewNsProp (msg->priv->last_node, msg->priv->xsi_ns, "type", xsi_type);
+	g_return_if_fail (SOUP_IS_SOAP_MESSAGE (msg));
+	priv = SOUP_SOAP_MESSAGE_GET_PRIVATE (msg);
+
+	xmlNewNsProp (priv->last_node, priv->xsi_ns, "type", xsi_type);
 }
 
 /**
  * soup_soap_message_set_null:
- * @msg: the %SoupSoapMessage.
+ * @msg: the #SoupSoapMessage.
  *
  * Sets the current element's XML Schema xsi:null attribute.
  */
 void
 soup_soap_message_set_null (SoupSoapMessage *msg)
 {
-	g_return_if_fail (SOUP_IS_SOAP_MESSAGE (msg));
+	SoupSoapMessagePrivate *priv;
 
-	xmlNewNsProp (msg->priv->last_node, msg->priv->xsi_ns, "null", "1");
+	g_return_if_fail (SOUP_IS_SOAP_MESSAGE (msg));
+	priv = SOUP_SOAP_MESSAGE_GET_PRIVATE (msg);
+
+	xmlNewNsProp (priv->last_node, priv->xsi_ns, "null", "1");
 }
 
 /**
  * soup_soap_message_add_attribute:
- * @msg: the %SoupSoapMessage.
+ * @msg: the #SoupSoapMessage.
  * @name: name of the attribute
  * @value: value of the attribute
  * @prefix: the namespace prefix
@@ -589,16 +622,19 @@ soup_soap_message_add_attribute (SoupSoapMessage *msg,
 				 const char *prefix,
 				 const char *ns_uri)
 {
-	g_return_if_fail (SOUP_IS_SOAP_MESSAGE (msg));
+	SoupSoapMessagePrivate *priv;
 
-	xmlNewNsProp (msg->priv->last_node,
+	g_return_if_fail (SOUP_IS_SOAP_MESSAGE (msg));
+	priv = SOUP_SOAP_MESSAGE_GET_PRIVATE (msg);
+
+	xmlNewNsProp (priv->last_node,
 		      fetch_ns (msg, prefix, ns_uri),
 		      name, value);
 }
 
 /**
  * soup_soap_message_add_namespace:
- * @msg: the %SoupSoapMessage.
+ * @msg: the #SoupSoapMessage.
  * @prefix: the namespace prefix
  * @ns_uri: the namespace URI, or NULL for empty namespace
  *
@@ -607,87 +643,101 @@ soup_soap_message_add_attribute (SoupSoapMessage *msg,
 void
 soup_soap_message_add_namespace (SoupSoapMessage *msg, const char *prefix, const char *ns_uri)
 {
-	g_return_if_fail (SOUP_IS_SOAP_MESSAGE (msg));
+	SoupSoapMessagePrivate *priv;
 
-	xmlNewNs (msg->priv->last_node, ns_uri ? ns_uri : "", prefix);
+	g_return_if_fail (SOUP_IS_SOAP_MESSAGE (msg));
+	priv = SOUP_SOAP_MESSAGE_GET_PRIVATE (msg);
+
+	xmlNewNs (priv->last_node, ns_uri ? ns_uri : "", prefix);
 }
 
 /**
- * soup_soap_set_default_namespace:
- * @msg: the %SoupSoapMessage.
+ * soup_soap_message_set_default_namespace:
+ * @msg: the #SoupSoapMessage.
  * @ns_uri: the namespace URI.
  *
- * Sets the default namespace to the URI specified in @ns_uri. The default
- * namespace becomes the namespace all non-explicitly namespaced child elements
- * fall into.
+ * Sets the default namespace to the URI specified in @ns_uri. The
+ * default namespace becomes the namespace all non-explicitly
+ * namespaced child elements fall into.
  */
 void
 soup_soap_message_set_default_namespace (SoupSoapMessage *msg, const char *ns_uri)
 {
+	SoupSoapMessagePrivate *priv;
+
 	g_return_if_fail (SOUP_IS_SOAP_MESSAGE (msg));
+	priv = SOUP_SOAP_MESSAGE_GET_PRIVATE (msg);
 
 	soup_soap_message_add_namespace (msg, NULL, ns_uri);
 }
 
 /**
  * soup_soap_message_set_encoding_style:
- * @msg: the %SoupSoapMessage.
+ * @msg: the #SoupSoapMessage.
  * @enc_style: the new encodingStyle value
  *
- * Sets the encodingStyle attribute on the current element to the value of
- * @enc_style.
+ * Sets the encodingStyle attribute on the current element to the
+ * value of @enc_style.
  */
 void
 soup_soap_message_set_encoding_style (SoupSoapMessage *msg, const char *enc_style)
 {
-	g_return_if_fail (SOUP_IS_SOAP_MESSAGE (msg));
+	SoupSoapMessagePrivate *priv;
 
-	xmlNewNsProp (msg->priv->last_node, msg->priv->soap_ns, "encodingStyle", enc_style);
+	g_return_if_fail (SOUP_IS_SOAP_MESSAGE (msg));
+	priv = SOUP_SOAP_MESSAGE_GET_PRIVATE (msg);
+
+	xmlNewNsProp (priv->last_node, priv->soap_ns, "encodingStyle", enc_style);
 }
 
 /**
  * soup_soap_message_reset:
- * @msg: the %SoupSoapMessage.
+ * @msg: the #SoupSoapMessage.
  *
  * Resets the internal XML representation of the SOAP message.
  */
 void
 soup_soap_message_reset (SoupSoapMessage *msg)
 {
+	SoupSoapMessagePrivate *priv;
+
 	g_return_if_fail (SOUP_IS_SOAP_MESSAGE (msg));
+	priv = SOUP_SOAP_MESSAGE_GET_PRIVATE (msg);
 
-	xmlFreeDoc (msg->priv->doc);
-	msg->priv->doc = xmlNewDoc ("1.0");
-	msg->priv->last_node = NULL;
+	xmlFreeDoc (priv->doc);
+	priv->doc = xmlNewDoc ("1.0");
+	priv->last_node = NULL;
 
-	g_free (msg->priv->action);
-	msg->priv->action = NULL;
-	msg->priv->body_started = FALSE;
+	g_free (priv->action);
+	priv->action = NULL;
+	priv->body_started = FALSE;
 
-	if (msg->priv->env_uri)
-		g_free (msg->priv->env_uri);
-	msg->priv->env_uri = NULL;
+	if (priv->env_uri)
+		g_free (priv->env_uri);
+	priv->env_uri = NULL;
 
-	if (msg->priv->env_prefix)
-		g_free (msg->priv->env_prefix);
-	msg->priv->env_prefix = NULL;
+	if (priv->env_prefix)
+		g_free (priv->env_prefix);
+	priv->env_prefix = NULL;
 }
 
 /**
  * soup_soap_message_persist:
- * @msg: the %SoupSoapMessage.
+ * @msg: the #SoupSoapMessage.
  *
- * Writes the serialized XML tree to the %SoupMessage's buffer.
+ * Writes the serialized XML tree to the #SoupMessage's buffer.
  */
 void
 soup_soap_message_persist (SoupSoapMessage *msg)
 {
+	SoupSoapMessagePrivate *priv;
 	xmlChar *body;
 	int len;
 
 	g_return_if_fail (SOUP_IS_SOAP_MESSAGE (msg));
+	priv = SOUP_SOAP_MESSAGE_GET_PRIVATE (msg);
 
-	xmlDocDumpMemory (msg->priv->doc, &body, &len);
+	xmlDocDumpMemory (priv->doc, &body, &len);
 
 	/* serialize to SoupMessage class */
 	soup_message_set_request (SOUP_MESSAGE (msg), "text/xml",
@@ -696,22 +746,26 @@ soup_soap_message_persist (SoupSoapMessage *msg)
 
 /**
  * soup_soap_message_get_namespace_prefix:
- * @msg: the %SoupSoapMessage.
+ * @msg: the #SoupSoapMessage.
  * @ns_uri: the namespace URI.
  *
- * Return value: The namespace prefix for @ns_uri or an empty string if @ns_uri
- * is set to the default namespace. If no namespace exists for the URI given,
- * NULL is returned.
+ * Returns the namespace prefix for @ns_uri (or an empty string if
+ * @ns_uri is set to the default namespace)
+ *
+ * Return value: The namespace prefix, or %NULL if no namespace exists
+ * for the URI given.
  */
 const char *
 soup_soap_message_get_namespace_prefix (SoupSoapMessage *msg, const char *ns_uri)
 {
+	SoupSoapMessagePrivate *priv;
 	xmlNsPtr ns = NULL;
 
 	g_return_val_if_fail (SOUP_IS_SOAP_MESSAGE (msg), NULL);
+	priv = SOUP_SOAP_MESSAGE_GET_PRIVATE (msg);
 	g_return_val_if_fail (ns_uri != NULL, NULL);
 
-	ns = xmlSearchNsByHref (msg->priv->doc, msg->priv->last_node, ns_uri);
+	ns = xmlSearchNsByHref (priv->doc, priv->last_node, ns_uri);
 	if (ns) {
 		if (ns->prefix)
 			return ns->prefix;
@@ -724,37 +778,42 @@ soup_soap_message_get_namespace_prefix (SoupSoapMessage *msg, const char *ns_uri
 
 /**
  * soup_soap_message_get_xml_doc:
- * @msg: the %SoupSoapMessage.
+ * @msg: the #SoupSoapMessage.
  *
- * Returns the internal XML representation tree of the %SoupSoapMessage pointed
- * to by @msg.
+ * Returns the internal XML representation tree of the
+ * #SoupSoapMessage pointed to by @msg.
  *
- * Return value: the xmlDocPtr representing the SOAP message.
+ * Return value: the #xmlDocPtr representing the SOAP message.
  */
 xmlDocPtr
 soup_soap_message_get_xml_doc (SoupSoapMessage *msg)
 {
-	g_return_val_if_fail (SOUP_IS_SOAP_MESSAGE (msg), NULL);
+	SoupSoapMessagePrivate *priv;
 
-	return msg->priv->doc;
+	g_return_val_if_fail (SOUP_IS_SOAP_MESSAGE (msg), NULL);
+	priv = SOUP_SOAP_MESSAGE_GET_PRIVATE (msg);
+
+	return priv->doc;
 }
 
 /**
  * soup_soap_message_parse_response:
- * @msg: the %SoupSoapMessage.
+ * @msg: the #SoupSoapMessage.
  *
  * Parses the response returned by the server.
  *
- * Return value: a %SoupSoapResponse representing the response from the server,
- * or %NULL if there was an error.
+ * Return value: a #SoupSoapResponse representing the response from
+ * the server, or %NULL if there was an error.
  */
 SoupSoapResponse *
 soup_soap_message_parse_response (SoupSoapMessage *msg)
 {
+	SoupSoapMessagePrivate *priv;
 	char *xmlstr;
 	SoupSoapResponse *soap_response;
 
 	g_return_val_if_fail (SOUP_IS_SOAP_MESSAGE (msg), NULL);
+	priv = SOUP_SOAP_MESSAGE_GET_PRIVATE (msg);
 
 	xmlstr = g_malloc0 (SOUP_MESSAGE (msg)->response.length + 1);
 	strncpy (xmlstr, SOUP_MESSAGE (msg)->response.body, SOUP_MESSAGE (msg)->response.length);
